
clear
set more off

import delimited "shares.dat"
ren v1 acid
ren v2 partyid
ren v3 year
ren v4 shares
ren v5 sch_all2
ren v6 literate2
ren v7 work_rural2
rename v# shi#, renumber
save temp.dta, replace

import delimited "sharesc.dat", clear
ren v1 acid
ren v2 partyid
ren v3 year
ren v4 sharesc
rename v# shic#, renumber

merge 1:1 acid partyid year using temp.dta
drop _merge

merge 1:1 acid partyid year using "formatlab.dta"
drop _merge

*remove abstention

forvalues i=1/1000 {
bysort mktid: egen q=total(shic`i')
replace shic`i'=shic`i'/q
drop q
}
egen sharesc2=rowmean(shic1-shic1000)

drop shic* shi*

label var shares "predicted shares within-sample"
label var sharesc "counterfactual shares without Nota"
label var sharesc2 "counterfactual shares without Nota or abstention"

keep if year==1 & state1==0

egen tag=tag(mktid) if cands3!=1

merge m:1 partyid using "partyid_short.dta"
drop if _merge==2
drop _merge

**********
*ANALYSIS
**********

* Table E.13 (without NOTA)

bysort mktid: egen pollpc=total(sharesc)
label var pollpc "turnout without Nota"
gen sharesc_v=sharesc/pollpc
label var sharesc_v "vote shares without Nota (share of voters only)"

gen dshare=sharesc2-sharesc
label var dshare "change in vote share as voting becomes compulsory"
sum dshare if year==1 & state1==0, det

gen dshare_v=sharesc2-sharesc_v
label var dshare_v "change in vote share as voting becomes compulsory (share of voters only)"
sum dshare_v if year==1 & state1==0, det

bysort mktid: egen mindshare_v=min(dshare_v) if cands3==0
label var mindshare_v "largest drop in a candidate's vote share in constituency"
sum mindshare_v if tag==1, det
bysort mktid: egen maxdshare_v=max(dshare_v) if cands3==0
label var maxdshare_v "largest increase in a candidate's vote share in constituency"
sum maxdshare_v if tag==1, det

gen dvote=totel*dshare
label var dvote "change in vote count as voting becomes compulsory (dshare*totel)"

egen electorate=total(totel) if tag==1
egen q=mean(electorate)
replace electorate=q
label var electorate "total number of voters in data"
drop q

* Table 7 (without NOTA)

bysort partyid: egen dshareparty_e=total(dvote)
replace dshareparty_e=dshareparty_e/electorate*100
label var dshareparty_e "change in share of electorate choosing each party (percentage points)"

gen ger2=sharesc*totel
egen yy=total(ger2) if cands3==1
gen notashare_e=yy/electorate
label var notashare_e "nota votes as a fraction of electorate"
sum notashare_e // this is dshare_e+dpollpc_e

bysort partyid: egen shareparty_e=total(ger2)
replace shareparty_e=shareparty_e/electorate*100
label var shareparty_e "share of electorate choosing each party (%)"
drop ger2 yy

table partyabbre, c(n dshare mean shareparty_e mean dshareparty_e )

*elections overturned
gsort mktid -shares
by mktid: gen order=_n
label var order "order of candidates in data"
gsort mktid -sharesc
by mktid: gen orderc=_n
label var orderc "order of candidates w/o Nota"
gen winnerc=1 if orderc==1
label var winnerc "1 if winnerc"
table partyabbre if cands3==0, c(n dshare mean shareparty_ mean dshareparty_e count winnerc)

gsort mktid -sharesc2
by mktid: gen orderc2=_n
label var orderc2 "order of candidates w/o Nota or abstention"
sum orderc2 if orderc==1 & orderc2!=1 // 117 election results changed (or 22.5%)
gen changed=0 if orderc==1
replace changed=1 if orderc==1 & orderc2!=1
sum changed, det

*browse mktid partyabbre orderc orderc2 if (order==1 | orderc==1) & order!=orderc
gen losefromc=partyabbre if orderc==1 & orderc2!=1
gen winfromc=partyabbre if orderc!=1 & orderc2==1
tab losefromc // extra losses
tab winfromc // extra wins


