
clear all;
format long;
global invA ns x1 x2 s_jt IV vfull dfull theta1 theti thetj cdid cdindex i_iv1 i_iv2 i_nota i_year i_dem1 i_dem2 i_s i_char1 i_mkt i_cand i_ran i_won ndemvars w;
formatlab=csvread('formatlab.csv'); % candidate level data
formatlab2=csvread('formatlab2.csv'); % ac level data
dummies=csvread('formatlab dummies.csv'); % party dummies & other characteristics treated as exogenous
varnames=textread('varnames.csv','%s')'; % variable names in a row

nobs=size(formatlab,1);

[truefalse, i_iv1] = ismember('icands2', varnames); % index of first IV
[truefalse, i_iv2] = ismember('i3cand_age_2', varnames); % index of last IV
%[truefalse, i_iv2] = ismember('i3minorit2_2', varnames); % if using 3rd instrument set
[truefalse, i_nota] = ismember('cands3', varnames);
[truefalse, i_year] = ismember('year', varnames);
[truefalse, i_dem1] = ismember('sch_all', varnames);
[truefalse, i_dem2] = ismember('work_rural', varnames);
[truefalse, i_s] = ismember('vsharesall', varnames);
[truefalse, i_char1] = ismember('cands2', varnames);
[truefalse, i_mkt] = ismember('mktid', varnames);
[truefalse, i_cand] = ismember('candnumber2_cum', varnames);
[truefalse, i_ran] = ismember('randist', varnames);
[truefalse, i_won] = ismember('wondist', varnames);
[truefalse, i_totel] = ismember('totel', varnames);
clear truefalse

ndemvars=i_dem2-i_dem1+1;

load demogr_avg;
cdid=formatlab(:,i_mkt); %market id
demavg_full=demogr_avg(cdid,:);
IV=[formatlab(:,i_iv1:i_iv2) formatlab(:,i_char1+3:i_nota) dummies formatlab(:,i_year) repmat(formatlab(:,i_nota),1,size(demavg_full,2)).*demavg_full];
%IV=[formatlab(:,i_iv1:i_iv2) formatlab(:,i_char1+3:i_nota) dummies formatlab(:,i_year)]; % if using 1st instrument set
clear demogr_avg demavg_full;

s_jt=[formatlab(:,i_s)];

% Set variables in linear part: characteristics (including nota), party dummies, year
x1=[formatlab(:,i_char1:i_nota) dummies formatlab(:,i_year)]; % Note that no constant since full set of party dummies.

% Set variables in nonlinear part: candidate characteristics (including nota)
x2=[formatlab(:,i_char1:i_char1+1) formatlab(:,i_nota)];
%x2=[formatlab(:,i_char1:i_char1+1) formatlab(:,i_nota) ones(nobs,1)]; % to include a constant (as in specifications (1-4) in Table E.6)
%x2=[formatlab(:,i_char1:i_char1+2) dummies(:,[9 18])]; % to include party dummies (as in specifications (3,4) in Table E.1)

ns=1000;  %number of simulated individuals per ac
nmkt=max(formatlab(:,i_mkt)); %number of market/years

%% Drawing or loading v's and demographics
% v1=randn(nmkt/2,ns*size(x2,2));
% rowNum = 1 + floor( (0:nmkt-1)/2);
% v=v1(rowNum,:);
% clear v1;
% save v v;
load v;

load demogr; % contains the demographics of 1000 simulated voters in each ac

cdindex=formatlab2(:,i_cand); %cumulative number of candidates
cdid=formatlab(:,i_mkt); %market id

vfull = v(cdid,:); % assign v to each observation
dfull = demogr(cdid,:); % assign demogr to each observation
w0 = formatlab2(:,i_totel); % weighting by size for GMM objective
w0 = w0/mean(w0);
w = w0(cdid,:);
clear w0;

%% Starting value for first step
 
% Nonlinear parameters used are indicated with 0/1 in matrix below. Columns: [sigma   sc_all literate  ruralw].
% Rows correspond to variables in x2. In main estimation: Female, Age, NOTA.
% For random coefficient specifications, only first column has 1's.

   theta2w= [   0  1   1   0; %nonlinear parameters
                0  1   0   1;
                0  0   0   1];
                                         
[theti, thetj, theta2]=find(theta2w); %theta2 is column with nonzero elements of theta2w

theta2w=full(sparse(theti, thetj, theta2));

invA = inv([IV'*IV]); % weight matrix

% compute the outside good market share by market
temp = cumsum(s_jt);
sum1 = temp(cdindex,:); %this assigns cumulative pollppercent to all observations
sum1(2:size(sum1,1),:) = diff(sum1);
outshr = 1.0 - sum1(cdid,:);

% run initial Logit
y = log(s_jt) - log(outshr);
mid = (x1.*repmat(w,1,size(x1,2)))'*IV*invA*IV';

% IV Logit
t = inv(mid*(x1.*repmat(w,1,size(x1,2))))*mid*(y.*w); % IV of log shares on X1 using IV as instruments

mvalold = x1*t;        % Fitted log shares (relative to S0)
mvalold = exp(mvalold);  % exp(delta) = exp(ln(S)-ln(S0))
oldt2 = zeros(size(theta2)); % Zero out old theta2

save mvalold mvalold oldt2
clear mid y outshr t oldt2 mvalold temp sum1
 

%% First step estimate using invA above as weighting matrix

options = optimoptions('patternsearch','TolFun',1e-6,'TolX',1e-6,'display','iter', 'UseParallel', false,'Cache','On', 'AccelerateMesh',true); 

fun=@ gmmobj_weighted; 
tic;
[theta2,fval,exitflag,output] = patternsearch(fun,theta2,[],[],[],[],[],[],[],options);
time_first=toc; 

load mvalold;
save mvalold_firststep mvalold oldt2;
load gmmresid
save gmmresid_firststep gmmresid;

delta = meanval(theta2);
temp1 = (x1.*repmat(w,1,size(x1,2)))'*IV;
temp2 = (delta.*w)'*IV;
theta1 = inv(temp1*invA*temp1')*temp1*invA*temp2';
clear temp1 temp2;
gmmresid = delta.*w - (x1.*repmat(w,1,size(x1,2)))*theta1;
mvalold=exp(delta);

save results_firststep theta2 theta1 fval invA delta;

theta2w=full(sparse(theti, thetj, theta2));

%% Second step

nkand=max(cdindex);
clusterid=cdid; % if clustering by ac/year
temp1=zeros(nkand,max(clusterid(:)));
for i=1:nkand 
    temp1(i,clusterid(i,1))=gmmresid(i);
end
Om=temp1*temp1'; % the block-diagonal uu' matrix (nobs x nobs)
clear temp1 gmmresid
b=IV'*Om*IV;
invA=inv(b);

oldt2=theta2;
save mvalold mvalold oldt2;
clear mvalold oldt2;

options = optimoptions('patternsearch','TolFun',1e-6,'TolX',1e-6,'display','iter', 'UseParallel', false,'Cache','On', 'AccelerateMesh',true); 
tic;
[theta2,fval,exitflag,output] = patternsearch(fun,theta2,[],[],[],[],[],[],[],options);
time_second=toc; 

save matlab_second;

%% Standard errors

delta = meanval(theta2);
temp1 = (x1.*repmat(w,1,size(x1,2)))'*IV;
temp2 = (delta.*w)'*IV;
theta1 = inv(temp1*invA*temp1')*temp1*invA*temp2';
clear temp1 temp2;
gmmresid = delta.*w - (x1.*repmat(w,1,size(x1,2)))*theta1;
mvalold=exp(delta);

theta2w=full(sparse(theti, thetj, theta2));

nkand=max(cdindex);
clusterid=cdid; % if clustering by ac/year
temp1=zeros(nkand,max(clusterid(:)));
for i=1:nkand 
    temp1(i,clusterid(i,1))=gmmresid(i);
end
Om=temp1*temp1'; % the block-diagonal uu' matrix (nobs x nobs)
clear temp1 gmmresid
b=IV'*Om*IV;

temp = jacob(mvalold,theta2,vfull,dfull); %this is the derivative of the errors w.r.t. theta2 (= partial delta / partial theta2)
a = [-x1.*repmat(w,1,size(x1,2)) temp.*repmat(w,1,size(temp,2))]'*IV;  %derivative of the moments w.r.t. theta (x1'IV is just the derivative w.r.t. theta1)
             %order above determines order in cov matrix. Now nonlinear parameters are at the end
vcov = inv(a*invA*a')*a*invA*b*invA*a'*inv(a*invA*a'); %heterosk errors Greene eqn. (18-11) / Cameron-Trivedi Table 6.3
clear temp

se=sqrt(diag(vcov)); % all se
t=size(se,1)-size(theta2,1);
se2w=full(sparse(theti,thetj,se(t+1:size(se,1)))); % nonlinear parameters se
se1=se(1:t,:); 
ger=[theta2w se2w];
ger2=[theta2w./se2w];
gerx1=[theta1 se1];

save results_second theta1 theta2 fval invA ger gerx1 delta;

%Newey-West D test of theta2=0

%constrained model: logit
sum1=accumarray(cdid,s_jt);
outshr = 1.0 - sum1(cdid,:);
y = log(s_jt) - log(outshr);
mid = (x1.*repmat(w,1,size(x1,2)))'*IV*invA*IV';
t = inv(mid*(x1.*repmat(w,1,size(x1,2))))*mid*(y.*w); % IV of log shares on X1 using IV as instruments
gmmresid_l=y.*w - (x1.*repmat(w,1,size(x1,2)))*t;
temp1 = gmmresid_l'*IV;
f_l = temp1*invA*temp1';
clear temp1;
d=f_l-fval
1-chi2cdf(d,size(theta2,1))